"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMonorepo = useMonorepo;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
const path_1 = require("path");
const globals_1 = require("@jest/globals");
const common_tags_1 = require("common-tags");
const jest_diff_1 = require("jest-diff");
function compareStrings(a, b) {
    return a.includes(b);
}
globals_1.expect.extend({
    toBeSimilarStringTo(received, expected) {
        const strippedReceived = (0, common_tags_1.oneLine) `${received}`.replace(/\s\s+/g, ' ');
        const strippedExpected = (0, common_tags_1.oneLine) `${expected}`.replace(/\s\s+/g, ' ');
        if (compareStrings(strippedReceived, strippedExpected)) {
            return {
                message: () => `expected
   ${received}
   not to be a string containing (ignoring indents)
   ${expected}`,
                pass: true,
            };
        }
        const diffString = (0, jest_diff_1.diff)((0, common_tags_1.stripIndent) `${expected}`, (0, common_tags_1.stripIndent) `${received}`, {
            expand: this.expand,
        });
        const hasExpect = diffString?.includes('- Expect');
        const message = hasExpect
            ? `Difference:\n\n${diffString}`
            : `expected
      ${received}
      to be a string containing (ignoring indents)
      ${expected}`;
        return {
            message: () => message,
            pass: false,
        };
    },
});
function findProjectDir(dirname) {
    const originalDirname = dirname;
    const cwd = process.cwd();
    const stopDir = (0, path_1.resolve)(cwd, '..');
    while (dirname !== stopDir) {
        try {
            if ((0, fs_1.existsSync)((0, path_1.resolve)(dirname, 'package.json'))) {
                return dirname;
            }
            dirname = (0, path_1.resolve)(dirname, '..');
        }
        catch (e) {
            // ignore
        }
    }
    throw new Error(`Coudn't find project's root from: ${originalDirname}`);
}
function useMonorepo({ dirname }) {
    const cwd = findProjectDir(dirname);
    return {
        correctCWD() {
            let spyProcessCwd;
            beforeEach(() => {
                spyProcessCwd = jest.spyOn(process, 'cwd').mockReturnValue(cwd);
            });
            afterEach(() => {
                spyProcessCwd.mockRestore();
            });
        },
    };
}
tslib_1.__exportStar(require("./mock-graphql-server.js"), exports);
tslib_1.__exportStar(require("./resolvers-common.js"), exports);
tslib_1.__exportStar(require("./typescript.js"), exports);
